@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 
 
 /* Check if we have a good smbusers username map file */
-int smb_usermap_ok(gchar *path)
+int smb_usermap_ok(gchar * path)
 {
     FILE *fp;
     char *line;
@@ -46,33 +46,33 @@ int smb_usermap_ok(gchar *path)
     int valid_root = 0, valid_guest = 0;
     int retval = 0;
 
-    if((fp=fopen(path, "r"))==NULL)
+    if((fp = fopen(path, "r")) == NULL)
     {
-	/* Dont show a dialog here */
-    	return retval;
+        /* Dont show a dialog here */
+        return retval;
     }
     fseek(fp, 0, SEEK_END);
     file_size = ftell(fp);
     rewind(fp);
 
-    line = allocate(file_size+1);
+    line = allocate(file_size + 1);
 
-    if( file_size > 1 )
-    while(fgets(line, file_size, fp)!=NULL)
+    if(file_size > 1)
+    while(fgets(line, file_size, fp) != NULL)
     {
-	if( strstr(line, "root") && strstr(line, "=") 
-	&& strstr(line, "administrator") && ! commented(line) )
-	valid_root = 1;
-	
-	if( strstr(line, "nobody") && strstr(line, "=") 
-	&& strstr(line, "smbguest") && ! commented(line) )
-	valid_guest = 1;
+        if(strstr(line, "root") && strstr(line, "=")
+           && strstr(line, "administrator") && !commented(line))
+           valid_root = 1;
+
+        if(strstr(line, "nobody") && strstr(line, "=")
+           && strstr(line, "smbguest") && !commented(line))
+           valid_guest = 1;
     }
     fclose(fp);
-    free(line);    
+    free(line);
 
-    if( valid_root && valid_guest )
-      retval = 1;
+    if(valid_root && valid_guest)
+        retval = 1;
 
     return retval;
 }
@@ -116,34 +116,34 @@ int add_standard_users()
     g_free(cmd);
 
     /* We want username mappings in /etc/samba/smbusers */
-    conf = g_strconcat(
-    "# Unix_name = SMB_Name1 SMB_Name2 ...\n",
-    "root = administrator\n",
-    "nobody = guest smbguest pcguest\n",
-    NULL);
+    conf = g_strconcat("# Unix_name = SMB_Name1 SMB_Name2 ...\n",
+        "root = administrator\n", "nobody = guest smbguest pcguest\n", NULL);
 
-    path = g_strdup_printf("%s", SAMBA_USERMAP);    
+    path = g_strdup_printf("%s", SAMBA_USERMAP);
     if( ! file_exists(path) || ! smb_usermap_ok(path) )
     {
-	if((fp=fopen(path, "w+"))==NULL)
-	{
-    	    info = g_strdup_printf(_("Failed adding default smbusers file here:\n%s\n"), SAMBA_USERMAP);
-    	    show_info(info);
-    	    g_free(info);
+        if((fp = fopen(path, "w+")) == NULL)
+        {
+            info = g_strdup_printf(_("Failed adding default smbusers file here:\n%s\n"),
+                                   SAMBA_USERMAP);
+            show_info(info);
+            g_free(info);
 
-    	    g_free(path);
-    	    g_free(conf);
-    	    return 0;
-	}
-	fputs(conf, fp);
-	fclose(fp);
+            g_free(path);
+            g_free(conf);
+            return 0;
+        }
+        fputs(conf, fp);
+        fclose(fp);
 
-    	info = g_strdup_printf(_("A new smbusers map file was added here:\n%s\n It has the following contents: \"root = administrator\" and \"nobody = smbguest\".\n"), SAMBA_USERMAP);
-    	show_info(info);
-    	g_free(info);
+        info = g_strdup_printf(_
+            ("A new smbusers map file was added here:\n%s\n It has the following contents: \"root = administrator\" and \"nobody = smbguest\".\n"),
+                                                  SAMBA_USERMAP);
+        show_info(info);
+        g_free(info);
     }
     g_free(path);
-    g_free(conf);    
+    g_free(conf);
 
     /* Add the NOBODY system group if it doesnt exist */
     name = g_strdup_printf("%s", NOBODY);
@@ -161,31 +161,32 @@ int add_standard_users()
         g_free(cmd);
     }
     g_free(name);
-    
+
     /* Add the NOBODY system user to the NOBODY group as a locked account */
     name = g_strdup_printf("%s", NOBODY);
     if( ! user_exists(name) )
     {
-        cmd = g_strdup_printf("%s '%s' -d /dev/null -c Nobody -s /dev/null -g '%s'", "useradd", name, name);
+        cmd = g_strdup_printf("%s '%s' -d /dev/null -c Nobody -s /dev/null -g '%s'", "useradd", name,
+                              name);
         if( ! run_command(cmd) )
         {
             printf("Error adding the system user: %s\n", name);
-    	    printf("The command was: %s\n", cmd);
+            printf("The command was: %s\n", cmd);
             g_free(cmd);
             g_free(name);
             return 0;
         }
         g_free(cmd);
 
-	/* To be really sure we check it again with the same function */
-	if( ! user_exists(name) )
-	{
-    	    info = g_strdup_printf(_("Failed adding the system user:\n%s\n"), name);
-    	    show_info(info);
-    	    g_free(info);
-    	    g_free(name);
-    	    return 0;
-	}
+        /* To be really sure we check it again with the same function */
+        if( ! user_exists(name) )
+        {
+            info = g_strdup_printf(_("Failed adding the system user:\n%s\n"), name);
+            show_info(info);
+            g_free(info);
+            g_free(name);
+            return 0;
+        }
     }
     g_free(name);
 
@@ -195,26 +196,27 @@ int add_standard_users()
     if( ! user_exists(name) )
     {
         /* Add the system user to the NOBODY group */
-        cmd = g_strdup_printf("%s '%s' -d /dev/null -c 'Samba guest account' -s /dev/null -g '%s'", "useradd", name, NOBODY);
+        cmd = g_strdup_printf("%s '%s' -d /dev/null -c 'Samba guest account' -s /dev/null -g '%s'",
+                              "useradd", name, NOBODY);
         if( ! run_command(cmd) )
         {
             printf("Error adding the system user: %s\n", name);
-    	    printf("The command was: %s\n", cmd);
+            printf("The command was: %s\n", cmd);
             g_free(cmd);
             g_free(name);
             return 0;
         }
         g_free(cmd);
 
-	/* To be really sure we check it again with the same function */
-	if( ! user_exists(name) )
-	{
-    	    info = g_strdup_printf(_("Failed adding the system user:\n%s\n"), name);
-    	    show_info(info);
-    	    g_free(info);
-    	    g_free(name);
-    	    return 0;
-	}
+        /* To be really sure we check it again with the same function */
+        if( ! user_exists(name) )
+        {
+            info = g_strdup_printf(_("Failed adding the system user:\n%s\n"), name);
+            show_info(info);
+            g_free(info);
+            g_free(name);
+            return 0;
+        }
     }
     g_free(name);
 
@@ -223,10 +225,10 @@ int add_standard_users()
     name = g_strdup_printf("%s", "smbguest");
     if( ! smbuser_exists(name) )
     {
-	if( ! add_locked_samba_user(name) )
-	{
-	    printf("Error adding standard samba user: %s\n", name);
-	}
+        if( ! add_locked_samba_user(name) )
+        {
+            printf("Error adding standard samba user: %s\n", name);
+        }
     }
     g_free(name);
 
@@ -254,10 +256,10 @@ int add_standard_users()
     name = g_strdup_printf("%s", "root");
     if( ! smbuser_exists(name) )
     {
-	if( ! add_locked_samba_user(name) )
-	{
-	    printf("Error adding standard samba user: %s\n", name);
-	}
+        if( ! add_locked_samba_user(name) )
+        {
+            printf("Error adding standard samba user: %s\n", name);
+        }
     }
     g_free(name);
 
