@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,10 +24,13 @@
 #include <string.h>
 #include "widgets.h"
 #include "gettext.h"
+#include "apply_server_settings.h"
 #include "reread_conf.h"
 
 
 void apply_button_clicked(struct w *widgets)
 {
+    apply_server_settings(widgets);
+
     reread_conf(widgets);
 }
