@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,25 +19,24 @@
 
 
 
-int
-chars_are_digits(char *buf)
+int chars_are_digits(char *buf)
 {
-    int i=0, match=0;
-    for(i=0; buf[i]!='\0'; i++)
+    int i = 0, match = 0;
+    for(i = 0; buf[i] != '\0'; i++)
     {
-        if( buf[i]=='\n' || buf[i]=='\r')
+        if( buf[i] == '\n' || buf[i] == '\r' )
         {
-           i--;
-	   break;
+            i--;
+            break;
         }
-	if( buf[i]=='0' || buf[i]=='1' || buf[i]=='2' || buf[i]=='3' || buf[i]=='4' 
-	 || buf[i]=='5' || buf[i]=='6' || buf[i]=='7' || buf[i]=='8' || buf[i]=='9' )
-	 match++;	 
+        if( buf[i] == '0' || buf[i] == '1' || buf[i] == '2' || buf[i] == '3' || buf[i] == '4'
+            || buf[i] == '5' || buf[i] == '6' || buf[i] == '7' || buf[i] == '8' || buf[i] == '9' )
+            match++;
     }
-    if( match && match==i )
+    if( match && match == i )
     {
-       return 1;
+        return 1;
     }
     else
-       return 0;    
+        return 0;
 }
