@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,31 +38,29 @@ void create_main_window(struct w *widgets)
     GtkCellRenderer *pixbuf_cell_renderer;
     GdkPixbuf *pixbuf;
 
-
-    /* Create the main window */    
+    /* Create the main window */
     widgets->main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_position(GTK_WINDOW (widgets->main_window), GTK_WIN_POS_CENTER);
+    gtk_window_set_position(GTK_WINDOW(widgets->main_window), GTK_WIN_POS_CENTER);
     gtk_widget_set_size_request(widgets->main_window, -1, 490);
 
-
     /* Set window information */
     info = g_strdup_printf("GADMIN-SAMBA %s", VERSION);
     gtk_window_set_title(GTK_WINDOW(widgets->main_window), info);
     g_free(info);
 
-    /* Set the main window icon */    
+    /* Set the main window icon */
     pixmap_directory = g_strdup_printf("%s/pixmaps/gadmin-samba", PACKAGE_DATA_DIR);
     add_pixmap_directory(pixmap_directory);
     g_free(pixmap_directory);
 
-    pixbuf_cell_renderer = gtk_cell_renderer_pixbuf_new();    
+    pixbuf_cell_renderer = gtk_cell_renderer_pixbuf_new();
     pixbuf = create_pixbuf("gadmin-samba.png");
-    g_object_set(pixbuf_cell_renderer, "pixbuf", pixbuf, NULL); 
+    g_object_set(pixbuf_cell_renderer, "pixbuf", pixbuf, NULL);
     gtk_window_set_icon(GTK_WINDOW(widgets->main_window), pixbuf);
     gdk_pixbuf_unref(pixbuf);
 
     widgets->main_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (widgets->main_window), widgets->main_vbox);
+    gtk_container_add(GTK_CONTAINER(widgets->main_window), widgets->main_vbox);
 
     /* Hboxes (down) */
     GtkWidget *toolbar_hbox = gtk_hbox_new(FALSE, 0);
@@ -84,87 +82,64 @@ void create_main_window(struct w *widgets)
 
     gtk_toolbar_set_style(GTK_TOOLBAR(main_toolbar), GTK_TOOLBAR_BOTH);
 
-    /* Activate button */    
-    GtkWidget *toolbar_icon_yes = gtk_image_new_from_stock("gtk-yes", 
-                                  gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    /* Activate button */
+    GtkWidget *toolbar_icon_yes = gtk_image_new_from_stock("gtk-yes",
+        gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *activate_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Activate"), 
-							  NULL, NULL,
-							  toolbar_icon_yes, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(activate_button), "clicked", 
-                             G_CALLBACK(activate_button_clicked), widgets);
+        GTK_TOOLBAR_CHILD_BUTTON, NULL, _("Activate"), NULL, NULL, toolbar_icon_yes, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(activate_button), "clicked",
+        G_CALLBACK(activate_button_clicked), widgets);
 
     /* Deactivate button */
-    GtkWidget *toolbar_icon_no = gtk_image_new_from_stock("gtk-no", 
-                                 gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *toolbar_icon_no = gtk_image_new_from_stock("gtk-no",
+        gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *deactivate_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Deactivate"),
-							  NULL, NULL,
-							  toolbar_icon_no, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(deactivate_button), "clicked", 
-                             G_CALLBACK(deactivate_button_clicked), widgets);
+        GTK_TOOLBAR_CHILD_BUTTON,
+        NULL, _("Deactivate"), NULL, NULL, toolbar_icon_no, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(deactivate_button), "clicked",
+        G_CALLBACK(deactivate_button_clicked), widgets);
 
 
     /* Apply button */
-    GtkWidget *toolbar_apply_icon = gtk_image_new_from_stock("gtk-refresh", 
-                                      gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *toolbar_apply_icon = gtk_image_new_from_stock("gtk-refresh",
+        gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *apply_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Apply"),
-							  NULL, NULL,
-							  toolbar_apply_icon, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(apply_button), "clicked", 
-                             G_CALLBACK(apply_button_clicked), widgets);
+        GTK_TOOLBAR_CHILD_BUTTON, NULL, _("Apply"), NULL, NULL, toolbar_apply_icon, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(apply_button), "clicked",
+        G_CALLBACK(apply_button_clicked), widgets);
 
 
     /* Settings button */
-    GtkWidget *toolbar_settings_icon = gtk_image_new_from_stock("gtk-index", 
-                                      gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *toolbar_settings_icon = gtk_image_new_from_stock("gtk-index",
+        gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *settings_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Settings"),
-							  NULL, NULL,
-							  toolbar_settings_icon, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(settings_button), "clicked", 
-                             G_CALLBACK(show_settings_window), widgets);
+        GTK_TOOLBAR_CHILD_BUTTON, NULL, _("Settings"), NULL, NULL, toolbar_settings_icon, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(settings_button), "clicked",
+        G_CALLBACK(show_settings_window), widgets);
 
 
     /* Help button */
-    GtkWidget *toolbar_icon_help = gtk_image_new_from_stock("gtk-help", 
-                                   gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *toolbar_icon_help = gtk_image_new_from_stock("gtk-help",
+        gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *help_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Help"),
-							  NULL, NULL,
-							  toolbar_icon_help, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(help_button), "clicked", 
-                             G_CALLBACK(show_help), widgets);
+        GTK_TOOLBAR_CHILD_BUTTON, NULL, _("Help"), NULL, NULL, toolbar_icon_help, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(help_button), "clicked", G_CALLBACK(show_help), widgets);
 
 
     /* About button */
-    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-about", 
-                                      gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-about",
+        gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *about_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("About"),
-							  NULL, NULL,
-							  toolbar_icon_about, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(about_button), "clicked", 
-                             G_CALLBACK(show_credits), widgets);
+        GTK_TOOLBAR_CHILD_BUTTON, NULL, _("About"), NULL, NULL, toolbar_icon_about, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(about_button), "clicked", G_CALLBACK(show_credits), widgets);
 
 
     /* Quit button */
-    GtkWidget *toolbar_icon_quit = gtk_image_new_from_stock("gtk-quit", 
-                                   gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *toolbar_icon_quit = gtk_image_new_from_stock("gtk-quit",
+        gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *quit_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Quit"),
-							  NULL, NULL,
-							  toolbar_icon_quit, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(quit_button), "clicked", 
-                             G_CALLBACK(gtk_main_quit), NULL);
+        GTK_TOOLBAR_CHILD_BUTTON, NULL, _("Quit"), NULL, NULL, toolbar_icon_quit, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(quit_button), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 
     /* The notebook */
     GtkWidget *notebook_vbox = gtk_vbox_new(FALSE, 0);
@@ -205,13 +180,9 @@ void create_main_window(struct w *widgets)
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox1, server_label, 0);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox2, user_label, 1);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox3, resource_label, 2);
-
-
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox4, maccts_label, 3);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox5, dom_mgmt_label, 4);
-
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox6, conn_label, 5);
-
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox7, disc_label, 6);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox8, security_label, 7);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox9, conf_label, 8);
@@ -228,7 +199,7 @@ void create_main_window(struct w *widgets)
 
     GtkWidget *status_spacer_label = gtk_label_new("");
     gtk_box_pack_start(GTK_BOX(status_hbox), status_spacer_label, TRUE, TRUE, 0);
-    gtk_misc_set_alignment (GTK_MISC (status_spacer_label), 0, 0);
+    gtk_misc_set_alignment(GTK_MISC(status_spacer_label), 0, 0);
 
     widgets->status_label = gtk_label_new(_("Status: unknown"));
     gtk_box_pack_start(GTK_BOX(status_hbox), widgets->status_label, FALSE, FALSE, 0);
