@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,15 +23,13 @@
 #include "make_settings_hseparators.h"
 
 
-void make_3columns_hseparator(GtkTable *table,
-                                 gint left_attach,
-                                 gint right_attach,
-                                 gint top_attach,
-                                 gint bottom_attach)
+void make_3columns_hseparator(GtkTable * table,
+    gint left_attach, gint right_attach, gint top_attach, gint bottom_attach)
 {
     GtkWidget *hsep;
 
     hsep = gtk_hseparator_new();
-    gtk_table_attach(table, hsep, left_attach, right_attach + 3, top_attach, bottom_attach, GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(table, hsep, left_attach, right_attach + 3, top_attach, bottom_attach,
+        GTK_FILL, GTK_EXPAND, 5, 5);
     gtk_widget_show(hsep);
 }
