@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,15 +29,7 @@ GtkWidget *make_progressbar_with_label(GtkTable *table,
 				 gint top_attach, 
                                  gint bottom_attach, 
 				 gint bar_length);
-/*
-GtkWidget *make_short_combo_with_label(GtkTable *table, 
-                                 const gchar *label_text, 
-				 gint left_attach, 
-				 gint right_attach, 
-				 gint top_attach, 
-                                 gint bottom_attach, 
-				 gint entry_length);
-*/
+
 GtkWidget *make_button(GtkTable *table, 
 				 gint left_attach, 
 				 gint right_attach, 
