@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,8 +40,8 @@ extern char global_macct_name[1024];
 void populate_macct_settings(struct w *widgets)
 {
     gchar *info;
-    gchar *utf8=NULL;
-    int i=0;
+    gchar *utf8 = NULL;
+    int i = 0;
     gchar *what, *val, *machine_name;
 
     machine_name = g_strdup_printf("%s", global_macct_name);
@@ -49,9 +49,9 @@ void populate_macct_settings(struct w *widgets)
     info = g_strdup_printf("%s", global_macct_name);
     if( info == NULL || strlen(info) < 1 )
     {
-	/* User not specified, clear all widgets */
-	for( i=0; i<2; i++)
-	  gtk_entry_set_text(GTK_ENTRY(widgets->macct_set_entry[i]), "");
+        /* User not specified, clear all widgets */
+        for(i = 0; i < 2; i++)
+            gtk_entry_set_text(GTK_ENTRY(widgets->macct_set_entry[i]), "");
     }
     g_free(info);
 
@@ -59,14 +59,15 @@ void populate_macct_settings(struct w *widgets)
     what = g_strdup_printf("comment");
     val = get_user_setting(machine_name, what);
     gtk_entry_set_text(GTK_ENTRY(widgets->macct_set_entry[1]), val);
-    g_free(what); g_free(val);
+    g_free(what);
+    g_free(val);
 
     /* Set the machine name */
-    if( machine_name!=NULL && strlen(machine_name) > 1 )
-      machine_name[strlen(machine_name)-1]='\0';
+    if( machine_name != NULL && strlen(machine_name) > 1 )
+        machine_name[strlen(machine_name) - 1] = '\0';
 
     gtk_entry_set_text(GTK_ENTRY(widgets->macct_set_entry[0]), machine_name);
-      
-    if( utf8!=NULL )
-      g_free(utf8);
+
+    if(utf8 != NULL)
+        g_free(utf8);
 }
