@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
 #include "show_info.h"
 
 
-int conf_ok(gchar *file_path)
+int conf_ok(gchar * file_path)
 {
     FILE *fp;
     long conf_size;
@@ -46,68 +46,68 @@ int conf_ok(gchar *file_path)
 
     /* The configuration is ok if gadmin-sambas settings
        contains "show_conf_question: (no OR false)" */
-    if((fp=fopen(file_path, "r"))==NULL)
+    if((fp = fopen(file_path, "r")) == NULL)
     {
-	/* Return false */
-	return retval;
+        /* Return false */
+        return retval;
     }
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
     rewind(fp);
-    line = allocate(conf_size+1);
+    line = allocate(conf_size + 1);
 
     if( conf_size > 1 )
-    while(fgets(line, conf_size, fp)!=NULL)
-    {
-	/* Skip commented options */
-	if( commented(line) )
-	  continue;
+        while(fgets(line, conf_size, fp) != NULL)
+        {
+            /* Skip commented options */
+            if( commented(line) )
+                continue;
 
-	if( strlen(line) > 5 )
-	{
-	    if( strstr(line, "show_conf_question:") 
-	    && (strstr(line, "false") || strstr(line, "no")) )
-	    {
-	        retval = 1;
-		break;
-	    }
-	}
-    }
-    fclose(fp);	
+            if( strlen(line) > 5 )
+            {
+                if( strstr(line, "show_conf_question:" )
+                    && (strstr(line, "false") || strstr(line, "no")) )
+                {
+                    retval = 1;
+                    break;
+                }
+            }
+        }
+    fclose(fp);
     free(line);
 
 
     /* If the security option is missing the conf is still bad */
-    if((fp=fopen(SAMBA_CONF, "r"))==NULL)
+    if((fp = fopen(SAMBA_CONF, "r")) == NULL)
     {
-	return retval;
+        return retval;
     }
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
     rewind(fp);
-    line = allocate(conf_size+1);
+    line = allocate(conf_size + 1);
 
     if( conf_size > 1 )
-    while(fgets(line, conf_size, fp)!=NULL)
-    {
-	/* Skip commented options */
-	if( commented(line) )
-	  continue;
-    
-	if( strlen(line) > 5 )
-	{
-	    if( strstr(line, "security=") || strstr(line, "security =") )
-	    {
-	        have_security = 1;
-		break;
-	    }
-	}
-    }
+        while(fgets(line, conf_size, fp) != NULL)
+        {
+            /* Skip commented options */
+            if( commented(line) )
+                continue;
+
+            if( strlen(line) > 5 )
+            {
+                if( strstr(line, "security=") || strstr(line, "security =") )
+                {
+                    have_security = 1;
+                    break;
+                }
+            }
+        }
 
     if( ! have_security )
-      retval = 0;
+        retval = 0;
 
-    fclose(fp);	
+    fclose(fp);
     free(line);
 
     return retval;
@@ -120,40 +120,43 @@ void backup_samba_conf(struct w *widgets)
 
     if( ! file_exists(SAMBA_CONF_BACKUP) && file_exists(SAMBA_CONF) )
     {
-	cmd = g_strdup_printf("cp %s %s", SAMBA_CONF, SAMBA_CONF_BACKUP);
-	if( ! run_command(cmd) )
-	{
-	    info = g_strdup_printf(_("Error: Could not backup the current configuration:\n%s\n"), SAMBA_CONF);
-	    show_info(info);
-	}
-	else
-	  {
-	     info = g_strdup_printf(_("The samba configuration was backed up here for safety:\n%s\n"), SAMBA_CONF_BACKUP);
-	     show_info(info);
-	  }
+        cmd = g_strdup_printf("cp %s %s", SAMBA_CONF, SAMBA_CONF_BACKUP);
+        if( ! run_command(cmd) )
+        {
+            info = g_strdup_printf(_("Error: Could not backup the current configuration:\n%s\n"),
+                SAMBA_CONF);
+            show_info(info);
+        }
+        else
+        {
+            info =  g_strdup_printf(_("The samba configuration was backed up here for safety:\n%s\n"),
+                SAMBA_CONF_BACKUP);
+            show_info(info);
+        }
 
-	g_free(cmd);
-	g_free(info);
+        g_free(cmd);
+        g_free(info);
     }
 }
 
 
+/* This backs up the old configuration and adds the default configuration */
 void add_standard_conf(struct w *widgets)
 {
-    /* This backs up the old configuration and adds the default configuration */
     FILE *fp;
     char *buffer;
     gchar *cmd, *info;
 
-    /* First take a backup of the old configuration as SAMBA_CONF_BACKUP if it doesnt exist */
+    /* First take a backup of the old configuration
+       as SAMBA_CONF_BACKUP if it doesnt exist */
     backup_samba_conf(widgets);
 
     /* Write the default configuration */
-    if((fp=fopen(SAMBA_CONF, "w+"))==NULL)
+    if((fp = fopen(SAMBA_CONF, "w+")) == NULL)
     {
-	info = g_strdup_printf(_("Cant write a new smb.conf here:\n%s\n"), SAMBA_CONF);
-	show_info(info);
-	return;
+        info = g_strdup_printf(_("Cant write a new smb.conf here:\n%s\n"), SAMBA_CONF);
+        show_info(info);
+        return;
     }
 
     buffer = allocate(100000);
@@ -173,7 +176,7 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "printcap name = cups\n");
     strcat(buffer, "load printers = yes\n");
     strcat(buffer, "cups options = raw\n");
-    strcat(buffer, "printing = cups\n"); /* Fixme: Combo: cups, bsd etc */
+    strcat(buffer, "printing = cups\n");    /* Fixme: Combo: cups, bsd etc */
 
     strcat(buffer, "guest account = smbguest\n");
 
@@ -188,7 +191,7 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "encrypt passwords = yes\n");
     strcat(buffer, "unix password sync = yes\n");
     strcat(buffer, "socket options = TCP_NODELAY SO_RCVBUF=8192 SO_SNDBUF=8192\n");
-    strcat(buffer, "local master = no\n"); /* Only one per subnet. */
+    strcat(buffer, "local master = no\n");  /* Only one per subnet. */
     strcat(buffer, "domain master = no\n");
     strcat(buffer, "preferred master = no\n");
     strcat(buffer, "domain logons = no\n");
@@ -205,11 +208,11 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "dns proxy = no\n");
     strcat(buffer, "preserve case = yes\n");
     strcat(buffer, "short preserve case = yes\n");
-    strcat(buffer, "client use spnego = no\n");
-    strcat(buffer, "client signing = no\n");
-    strcat(buffer, "client schannel = no\n");
-    strcat(buffer, "server signing = no\n");
-    strcat(buffer, "server schannel = no\n");
+    strcat(buffer, "client use spnego = yes\n");
+    strcat(buffer, "client signing = yes\n");
+    strcat(buffer, "client schannel = yes\n");
+    strcat(buffer, "server signing = yes\n");
+    strcat(buffer, "server schannel = yes\n");
     strcat(buffer, "nt pipe support = yes\n");
     strcat(buffer, "nt status support = yes\n");
     strcat(buffer, "allow trusted domains = no\n");
@@ -233,18 +236,18 @@ void add_standard_conf(struct w *widgets)
 
     strcat(buffer, "passwd program = /usr/bin/passwd '%u'\n");
 
-/* Doesnt seem to work    info = g_strdup_printf("root directory = %s/lib/samba/root\n", LOCALSTATEDIR);
-    strcat(buffer, info);
-    g_free(info);
-*/
-    strcat(buffer, "passwd chat = *New*password* %n\\n *ReType*new*password* %n\\n *passwd*changed*\\n\n");
-    strcat(buffer, "add user script = /usr/sbin/useradd -d /dev/null -c 'Samba User Account' -s /dev/null '%u'\n");
-    strcat(buffer, "add user to group script=/usr/sbin/useradd -d /dev/null -c 'Samba User Account' -s /dev/null -g '%g' '%u'\n");
+    strcat(buffer,
+        "passwd chat = *New*password* %n\\n *ReType*new*password* %n\\n *passwd*changed*\\n\n");
+    strcat(buffer,
+        "add user script = /usr/sbin/useradd -d /dev/null -c 'Samba User Account' -s /dev/null '%u'\n");
+    strcat(buffer,
+        "add user to group script=/usr/sbin/useradd -d /dev/null -c 'Samba User Account' -s /dev/null -g '%g' '%u'\n");
     strcat(buffer, "add group script = /usr/sbin/groupadd '%g'\n");
     strcat(buffer, "delete user script = /usr/sbin/userdel '%u'\n");
     strcat(buffer, "delete user from group script = /usr/sbin/userdel '%u' '%g'\n");
     strcat(buffer, "delete group script = /usr/sbin/groupdel '%g'\n");
-    strcat(buffer, "add machine script = /usr/sbin/useradd -d /dev/null -g sambamachines -c 'Samba Machine Account' -s /dev/null -M '%u'\n");
+    strcat(buffer,
+        "add machine script = /usr/sbin/useradd -d /dev/null -g sambamachines -c 'Samba Machine Account' -s /dev/null -M '%u'\n");
     strcat(buffer, "machine password timeout = 120\n");
     strcat(buffer, "idmap uid = 16777216-33554431\n");
     strcat(buffer, "idmap gid = 16777216-33554431\n");
@@ -271,7 +274,6 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writable = yes\n");
     strcat(buffer, "guest ok = no\n");
-    strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
@@ -287,7 +289,6 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writable = no\n");
     strcat(buffer, "guest ok = no\n");
-    strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
@@ -305,13 +306,12 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writable = yes\n");
     strcat(buffer, "guest ok = no\n");
-    strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
     strcat(buffer, "create mode = 0600\n");
     strcat(buffer, "directory mask = 0700\n");
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
-    
+
     strcat(buffer, "\n");
     strcat(buffer, "[printers]\n");
     strcat(buffer, "comment = All Printers\n");
@@ -321,7 +321,6 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writable = no\n");
     strcat(buffer, "guest ok = no\n");
-    strcat(buffer, "public = no\n");
     strcat(buffer, "printable = yes\n");
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
@@ -360,25 +359,26 @@ void add_standard_conf(struct w *widgets)
     free(buffer);
 
 
-    if( GTK_IS_WINDOW(widgets->default_conf_question_window) )
-      gtk_widget_destroy(widgets->default_conf_question_window);
-
+    if( widgets->default_conf_question_window != NULL )
+    {
+        gtk_widget_destroy(widgets->default_conf_question_window);
+        widgets->default_conf_question_window = NULL;
+    }
     populate_gadmin_samba(widgets);
 
     /* Create default directories */
-    cmd = g_strdup_printf("mkdir -p '%s/lib/samba/netlogon' '%s/lib/samba/pdf-documents' '%s/lib/samba/profiles/root' '%s/log/samba'\n",
-    LOCALSTATEDIR, LOCALSTATEDIR, LOCALSTATEDIR, LOCALSTATEDIR);
-    if((fp=popen(cmd, "w"))==NULL)
+    cmd = g_strdup_printf
+        ("mkdir -p '%s/lib/samba/netlogon' '%s/lib/samba/pdf-documents' '%s/lib/samba/profiles/root' '%s/log/samba'\n",
+        LOCALSTATEDIR, LOCALSTATEDIR, LOCALSTATEDIR, LOCALSTATEDIR);
+    if((fp = popen(cmd, "w")) == NULL)
     {
         perror("popen");
         info = g_strconcat(_("Failed to create directories:\n%s\n"),
-        LOCALSTATEDIR, "/lib/samba/netlogon\n",
-        LOCALSTATEDIR, "/lib/samba/pdf-documents\n",
-        LOCALSTATEDIR, "/lib/samba/profiles/root\n",
-        LOCALSTATEDIR, "/log/samba\n",
-        NULL);
+            LOCALSTATEDIR, "/lib/samba/netlogon\n",
+            LOCALSTATEDIR, "/lib/samba/pdf-documents\n",
+            LOCALSTATEDIR, "/lib/samba/profiles/root\n", LOCALSTATEDIR, "/log/samba\n", NULL);
         show_info(info);
-	g_free(info);
+        g_free(info);
         g_free(cmd);
         return;
     }
@@ -387,12 +387,13 @@ void add_standard_conf(struct w *widgets)
 
     /* Chmod the profiles directory */
     cmd = g_strdup_printf("chmod 1755 %s/lib/samba/profiles\n", LOCALSTATEDIR);
-    if((fp=popen(cmd, "w"))==NULL)
+    if((fp = popen(cmd, "w")) == NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed chmodding directory: %s/lib/samba/profiles\n"), LOCALSTATEDIR);
+        info = g_strdup_printf(_("Failed chmodding directory: %s/lib/samba/profiles\n"),
+            LOCALSTATEDIR);
         show_info(info);
-	g_free(info);
+        g_free(info);
         g_free(cmd);
         return;
     }
@@ -401,12 +402,13 @@ void add_standard_conf(struct w *widgets)
 
     /* Create the samba root users home directory */
     cmd = g_strdup_printf("mkdir -p '%s/lib/samba/root'\n", LOCALSTATEDIR);
-    if((fp=popen(cmd, "w"))==NULL)
+    if((fp = popen(cmd, "w")) == NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed to create directory: %s/%s\n"), LOCALSTATEDIR, "/lib/samba/root");
+        info = g_strdup_printf(_("Failed to create directory: %s/%s\n"), LOCALSTATEDIR,
+            "/lib/samba/root");
         show_info(info);
-	g_free(info);
+        g_free(info);
         g_free(cmd);
         return;
     }
@@ -430,6 +432,7 @@ void add_standard_conf(struct w *widgets)
 void dont_add_standard_conf(struct w *widgets)
 {
     gtk_widget_destroy(widgets->default_conf_question_window);
+    widgets->default_conf_question_window = NULL;
     populate_gadmin_samba(widgets);
 }
 
@@ -454,7 +457,8 @@ void create_standard_conf_question(struct w *widgets)
 
     widgets->default_conf_question_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_widget_set_size_request(widgets->default_conf_question_window, 550, 340);
-    gtk_window_set_title(GTK_WINDOW(widgets->default_conf_question_window), _("GADMIN-SAMBA Question"));
+    gtk_window_set_title(GTK_WINDOW(widgets->default_conf_question_window),
+        _("GADMIN-SAMBA Question"));
     gtk_window_set_position(GTK_WINDOW(widgets->default_conf_question_window), GTK_WIN_POS_CENTER);
 
     vbox18 = gtk_vbox_new(FALSE, 0);
@@ -467,7 +471,8 @@ void create_standard_conf_question(struct w *widgets)
 
     scrolledwindow18 = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(vbox18), scrolledwindow18, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow18), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow18), GTK_POLICY_AUTOMATIC,
+        GTK_POLICY_AUTOMATIC);
 
     default_question_textview = gtk_text_view_new();
     gtk_container_add(GTK_CONTAINER(scrolledwindow18), default_question_textview);
@@ -477,17 +482,15 @@ void create_standard_conf_question(struct w *widgets)
     gtk_text_view_set_left_margin(GTK_TEXT_VIEW(default_question_textview), 30);
 
 
-    text = g_strconcat(
-    _("GADMIN-SAMBA could not find SAMBAs configuration (smb.conf) or the current\n"),
-    _("configuration doesnt have all the features that GADMIN-SAMBA requires.\n\n"),
-
-    _("Do you want to overwrite the current samba configuration ?\n"),
-
-    _("\t\t\t(If you dont know then press yes)\n"),
-    NULL);
+    text = g_strconcat(_
+        ("GADMIN-SAMBA could not find SAMBAs configuration (smb.conf) or the current\n"),
+        _("configuration doesnt have all the features that GADMIN-SAMBA requires.\n\n"),
+        _("Do you want to overwrite the current samba configuration ?\n"),
+        _("\t\t\t(If you dont know then press yes)\n"), NULL);
 
     utf8 = g_locale_to_utf8(text, strlen(text), NULL, NULL, NULL);
-    gtk_text_buffer_set_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(default_question_textview)), utf8, -1);
+    gtk_text_buffer_set_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(default_question_textview)),
+        utf8, -1);
     g_free(text);
 
 
@@ -530,95 +533,97 @@ void create_standard_conf_question(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbox99), label185, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label185), GTK_JUSTIFY_LEFT);
 
-    if( utf8!=NULL )
-      g_free(utf8);
+    if(utf8 != NULL)
+        g_free(utf8);
 
 
     g_signal_connect_swapped(G_OBJECT(yes_default_question_button), "clicked",
-                             G_CALLBACK(add_standard_conf), widgets);
+        G_CALLBACK(add_standard_conf), widgets);
 
     g_signal_connect_swapped(G_OBJECT(no_default_question_button), "clicked",
-                             G_CALLBACK(dont_add_standard_conf), widgets);
+        G_CALLBACK(dont_add_standard_conf), widgets);
 
     gtk_widget_show_all(widgets->default_conf_question_window);
 
 
-    /* The gadmin-samba settings directory doesnt exist, make it (could be due to bad packaging etc) */
+    /* Create the gadmin-samba settings directory if it doesnt exist. */
     if( ! file_exists(APPCONFDIR) )
     {
-	cmd = g_strdup_printf("mkdir -p '%s'", APPCONFDIR);
-	if( ! run_command(cmd) )
-	{
-    	    info = g_strdup_printf(_("Error: cant create the settings directory here:\n%s\n"), APPCONFDIR);
-    	    show_info(info);
-	    g_free(info);
-	    g_free(cmd);
-	    return;
-	}
-	g_free(cmd);
+        cmd = g_strdup_printf("mkdir -p '%s'", APPCONFDIR);
+        if( ! run_command(cmd) )
+        {
+            info = g_strdup_printf(_("Error: cant create the settings directory here:\n%s\n"),
+                APPCONFDIR);
+            show_info(info);
+            g_free(info);
+            g_free(cmd);
+            return;
+        }
+        g_free(cmd);
     }
 
     /* The settings file doesnt exist, create and write the setting to it */
     if( ! file_exists(SETTINGS_FILE) )
     {
-	if((fp=fopen(SETTINGS_FILE, "w+"))==NULL)
-	{
-    	    info = g_strdup_printf(_("Error: cant write the settings file here:\n%s\n"), SETTINGS_FILE);
-    	    show_info(info);
-	    g_free(info);
-	    return;
-	}
-	fputs("show_conf_question: false\n", fp);
-	fclose(fp);
-	return;
+        if((fp = fopen(SETTINGS_FILE, "w+")) == NULL)
+        {
+            info =  g_strdup_printf(_("Error: cant write the settings file here:\n%s\n"),
+                SETTINGS_FILE);
+            show_info(info);
+            g_free(info);
+            return;
+        }
+        fputs("show_conf_question: false\n", fp);
+        fclose(fp);
+        return;
     }
 
 
     /* Gather old values and re/write 'show_conf_question: false' to gadmin-sambas settings */
-    if((fp=fopen(SETTINGS_FILE, "r"))==NULL)
+    if((fp = fopen(SETTINGS_FILE, "r")) == NULL)
     {
-    	info = g_strdup_printf(_("Error: cant write the settings file here:\n%s\n"), SETTINGS_FILE);
-    	show_info(info);
-	g_free(info);
-	return;
+        info = g_strdup_printf(_("Error: cant write the settings file here:\n%s\n"), SETTINGS_FILE);
+        show_info(info);
+        g_free(info);
+        return;
     }
 
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
     rewind(fp);
 
-    line = allocate(conf_size+1);
-    conf = allocate(conf_size+1024);
-      
+    line = allocate(conf_size + 1);
+    conf = allocate(conf_size + 1024);
+
     if( conf_size > 1 )
-    while(fgets(line, conf_size, fp)!=NULL)
-    {
-	if( strlen(line) > 5 )
-	{
-	    if( strstr(line, "show_conf_question:") )
-	    {
-		found_conf_question = 1;
-	        strcat(conf, "show_conf_question: false\n");
-		break;
-	    }
-	    else
-	      strcat(conf, line);
-	}
-    }
-    fclose(fp);	
+        while(fgets(line, conf_size, fp) != NULL)
+        {
+            if( strlen(line) > 5 )
+            {
+                if( strstr(line, "show_conf_question:") )
+                {
+                    found_conf_question = 1;
+                    strcat(conf, "show_conf_question: false\n");
+                    break;
+                }
+                else
+                    strcat(conf, line);
+            }
+        }
+    fclose(fp);
     free(line);
 
     /* If theres no 'show_conf_question: false' line, add one */
     if( ! found_conf_question )
-      strcat(conf, "show_conf_question: false\n");
+        strcat(conf, "show_conf_question: false\n");
 
     /* Write the altered conf */
-    if((fp=fopen(SETTINGS_FILE, "w+"))==NULL)
+    if((fp = fopen(SETTINGS_FILE, "w+")) == NULL)
     {
         info = g_strdup_printf(_("Error: cant write the settings file here:\n%s\n"), SETTINGS_FILE);
         show_info(info);
-	g_free(info);
-	return;
+        g_free(info);
+        return;
     }
     fputs(conf, fp);
     fclose(fp);
