@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 extern struct w *widgets;
 
-char * process_running(char process[1024]); //, char extmatch[1024]);
+char * process_running(char process[1024]);
 
 int status_update(struct w *widgets);
 
